@@ -555,9 +555,9 @@ clutter_box_layout_set_container (ClutterLayoutManager *layout,
       /* we need to change the :request-mode of the container
        * to match the orientation
        */
-      request_mode = (priv->is_vertical)
-                   ? CLUTTER_REQUEST_WIDTH_FOR_HEIGHT
-                   : CLUTTER_REQUEST_HEIGHT_FOR_WIDTH;
+      request_mode = (priv->is_vertical
+                      ? CLUTTER_REQUEST_HEIGHT_FOR_WIDTH
+                      : CLUTTER_REQUEST_WIDTH_FOR_HEIGHT);
       clutter_actor_set_request_mode (CLUTTER_ACTOR (priv->container),
                                       request_mode);
     }
@@ -919,10 +919,7 @@ clutter_box_layout_allocate (ClutterLayoutManager   *layout,
     }
 
   if (n_expand_children == 0)
-    {
-      extra_space = 0;
-      n_expand_children = 1;
-    }
+    extra_space = 0;
   else
     {
       if (priv->is_vertical)
