@@ -60,6 +60,16 @@ typedef int (*SwapIntervalProc)  (int           interval);
 typedef void (*CopySubBufferProc)(Display *dpy,
                                   GLXDrawable drawable,
                                   int x, int y, int width, int height);
+typedef void (*BlitFramebufferProc) (GLint      srcX0,
+                                     GLint      srcY0,
+                                     GLint      srcX1,
+                                     GLint      srcY1,
+                                     GLint      dstX0,
+                                     GLint      dstY0,
+                                     GLint      dstX1,
+                                     GLint      dstY1,
+                                     GLbitfield mask,
+                                     GLenum     filter);
 
 struct _ClutterBackendGLX
 {
@@ -81,8 +91,12 @@ struct _ClutterBackendGLX
   SwapIntervalProc       swap_interval;
   gint                   dri_fd;
   ClutterGLXVBlankType   vblank_type;
+  unsigned int           last_video_sync_count;
 
+  gboolean               can_blit_sub_buffer;
   CopySubBufferProc      copy_sub_buffer;
+  BlitFramebufferProc    blit_framebuffer;
+  gboolean               blit_sub_buffer_is_synchronized;
 
   /* props */
   Atom atom_WM_STATE;
@@ -100,6 +114,11 @@ gboolean
 _clutter_backend_glx_get_fbconfig (ClutterBackendGLX *backend_x11,
                                    GLXFBConfig       *config);
 
+void
+_clutter_backend_glx_blit_sub_buffer (ClutterBackendGLX *backend_glx,
+                                      GLXDrawable drawable,
+                                      int x, int y, int width, int height);
+
 G_END_DECLS
 
 #endif /* __CLUTTER_BACKEND_GLX_H__ */
